@@ -34,7 +34,7 @@ pub enum AuditLogChangeKey {
     Mute,
     Name,
     Nick,
-    Nsfw,
+    NsfwLevel,
     OwnerId,
     PermissionOverwrites,
     Permissions,
@@ -51,6 +51,7 @@ pub enum AuditLogChangeKey {
     RulesChannelId,
     SplashHash,
     SystemChannelId,
+    PrivacyLevel,
     Temporary,
     Topic,
     Type,
