@@ -11,13 +11,29 @@ pub struct Team {
     pub icon: Option<String>,
     pub id: TeamId,
     pub members: Vec<TeamMember>,
+    pub name: String,
     pub owner_user_id: UserId,
 }
 
 #[cfg(test)]
 mod tests {
     use super::{Team, TeamId, UserId};
+    use serde::{Deserialize, Serialize};
     use serde_test::Token;
+    use static_assertions::{assert_fields, assert_impl_all};
+    use std::{fmt::Debug, hash::Hash};
+
+    assert_fields!(Team: icon, id, members, name, owner_user_id);
+
+    assert_impl_all!(
+        Team: Clone,
+        Debug,
+        Deserialize<'static>,
+        Eq,
+        Hash,
+        PartialEq,
+        Serialize
+    );
 
     #[test]
     fn test_team() {
@@ -25,6 +41,7 @@ mod tests {
             icon: Some("hash".to_owned()),
             id: TeamId(1),
             members: Vec::new(),
+            name: "team name".into(),
             owner_user_id: UserId(2),
         };
 
@@ -33,7 +50,7 @@ mod tests {
             &[
                 Token::Struct {
                     name: "Team",
-                    len: 4,
+                    len: 5,
                 },
                 Token::Str("icon"),
                 Token::Some,
@@ -44,6 +61,8 @@ mod tests {
                 Token::Str("members"),
                 Token::Seq { len: Some(0) },
                 Token::SeqEnd,
+                Token::Str("name"),
+                Token::Str("team name"),
                 Token::Str("owner_user_id"),
                 Token::NewtypeStruct { name: "UserId" },
                 Token::Str("2"),
